@@ -7,6 +7,7 @@ use bevy::window::WindowResized;
 
 use bevy_asset_loader::AssetLoader;
 
+use crate::help::help_panel::HelpPanel;
 use crate::theme::theme_colors::UiColors;
 use crate::{prelude::*, settings::layout_settings::LayoutMode};
 use crate::ui::viewer::TabViewerPlugin;
@@ -21,6 +22,7 @@ use super::app_state::{NotationAppState, TabPathes};
 pub struct NotationPlugins;
 impl PluginGroup for NotationPlugins {
     fn build(&mut self, group: &mut PluginGroupBuilder) {
+        group.add(FontPlugin);
         group.add(EntryPlugin);
         group.add(MelodyPlugin);
         group.add(LyricsPlugin);
@@ -42,6 +44,8 @@ impl PluginGroup for NotationPlugins {
 pub struct NotationApp;
 
 impl NotationApp {
+    pub const TITLE:&'static str = "Notation Viewer";
+
     pub fn new_builder(title: &str) -> AppBuilder {
         let mut app = App::build();
         AssetLoader::new(NotationAssetsStates::Loading, NotationAssetsStates::Loaded)
@@ -56,8 +60,11 @@ impl NotationApp {
         app.insert_resource(ClearColor(UiColors::default().app_background));
         app.add_plugin(bevy_easings::EasingsPlugin);
 
+        app.add_plugin(UtilsPlugin);
+
         app.init_resource::<NotationTheme>();
         app.init_resource::<NotationSettings>();
+        app.init_resource::<HelpPanel>();
         app.add_plugins(NotationPlugins);
 
         #[cfg(target_arch = "wasm32")]
@@ -103,6 +110,9 @@ impl NotationApp {
 
         app.add_startup_system(setup_camera.system());
 
+        #[cfg(debug_assertions)]
+        app.add_startup_system(setup_hot_reloading.system());
+
         app.add_system_set(
             SystemSet::on_enter(NotationAssetsStates::Loaded)
                 .with_system(setup_window_size.system())
@@ -114,6 +124,7 @@ impl NotationApp {
                 .with_system(handle_mouse_inputs.system())
                 .with_system(handle_touch_inputs.system())
                 .with_system(load_tab.system())
+                .with_system(on_tab_asset.system())
         );
 
         extra(&mut app);
@@ -134,9 +145,35 @@ fn setup_camera(mut commands: Commands) {
     commands.spawn_bundle(OrthographicCameraBundle::new_2d());
 }
 
+/*
+ * The open tab logic is using some trick in the asset server, which can load from absolute path
+ * (outside assets folder), but the hot reloading is not working this way.
+ * Ideally can use hot-reloading to update tabs automatically, but that means need to patch bevy
+ * to bypass the assumption with asset path under assets folder in reloading.
+ *
+ * Only enabling for debug build, the hot reloading works really nice for help pages.
+ *
+ * The crash error is:
+ *
+ * thread 'Compute Task Pool (2)' panicked at 'called `Result::unwrap()` on an `Err` value: StripPrefixError(())', C:\Users\yjpark\scoop\persist\rustup-msvc\.cargo\registry\src\github.com-1ecc6299db9ec823\bevy_asset-0.5.1\src\io\file_asset_io.rs:135:84
+ */
+fn setup_hot_reloading(asset_server: Res<AssetServer>) {
+    asset_server.watch_for_changes().unwrap();
+}
+
+fn on_tab_asset(
+    mut evts: EventReader<AssetEvent<TabAsset>>,
+) {
+    for evt in evts.iter() {
+        println!("AssetEvent<TabAsset> {:?}", evt);
+    }
+}
+
 fn load_tab(
     mut commands: Commands,
     time: Res<Time>,
+    asset_server: Res<AssetServer>,
+    mut windows: ResMut<Windows>,
     mut state: ResMut<NotationAppState>,
     mut theme: ResMut<NotationTheme>,
     entities: Query<Entity, With<GlobalTransform>>,
@@ -168,16 +205,22 @@ fn load_tab(
             }
             return;
         }
+        asset_server.free_unused_assets();
         if state._load_tab_delay_seconds > 0.0 {
             state._load_tab_delay_seconds -= time.delta_seconds();
             println!("load_tab(): Waiting to Load tab: -> {}", state._load_tab_delay_seconds);
             return;
         }
         println!("\nload_tab(): Loading: {}", state.tab_path);
-        if let Some(asset) = assets.get(&state.tab_asset) {
+        let tab_asset: Handle<TabAsset> = asset_server.load(state.tab_path.as_str());
+        if let Some(asset) = assets.get(&tab_asset) {
             match Tab::try_parse_arc(asset.tab.clone()) {
                 Ok(tab) => {
                     state.tab = Some(tab.clone());
+                    if let Some(window) = windows.get_primary_mut() {
+                        let title = format!("{} - {}", NotationApp::TITLE, state.tab_path);
+                        window.set_title(title);
+                    }
                     theme._bypass_systems = false;
                     evts.send(AddTabEvent(tab));
                 }
@@ -204,11 +247,17 @@ fn handle_keyboard_inputs(
     if app_state.tab.is_none() {
         return;
     }
-    if keyboard_input.just_released(KeyCode::LControl) {
-        app_state.hide_control = !app_state.hide_control;
+    if keyboard_input.just_released(KeyCode::Tab) {
+        app_state.show_control = !app_state.show_control;
         if !ControlView::HUD_MODE {
             window_resized_evts.send(WindowResizedEvent());
         }
+    } else if keyboard_input.just_released(KeyCode::F1)
+            || keyboard_input.just_released(KeyCode::H) {
+        app_state.show_help = !app_state.show_help;
+    } else if keyboard_input.just_released(KeyCode::F5)
+            || keyboard_input.just_released(KeyCode::R) {
+        Control::reload_tab(&mut app_state, &mut theme);
     } else if keyboard_input.just_released(KeyCode::Space) {
         Control::play_or_pause(&mut midi_state, &mut play_control_evts);
     } else if keyboard_input.just_released(KeyCode::Return) {
@@ -278,20 +327,22 @@ fn handle_mouse_inputs(
     if app_state.tab.is_none() {
         return;
     }
-    if mouse_input.just_released(MouseButton::Left) {
+    let cursor_position =
         windows
             .get_primary()
-            .and_then(|x| x.cursor_position())
-            .map(|cursor_position| {
-                //println!("handle_inputs() -> MouseClickedEvent({:?})", cursor_position);
-                mouse_clicked.send(MouseClickedEvent { cursor_position });
-            });
+            .and_then(|x| x.cursor_position());
+    if cursor_position.is_none() {
+        return;
+    }
+    let cursor_position = cursor_position.unwrap();
+    if mouse_input.just_released(MouseButton::Left) {
+        mouse_clicked.send(MouseClickedEvent { cursor_position });
     } else if mouse_input.just_pressed(MouseButton::Right) {
     } else if mouse_input.just_released(MouseButton::Right) {
     } else if mouse_input.pressed(MouseButton::Right) {
         for event in mouse_motion_events.iter() {
             //println!("handle_inputs() -> MouseDraggedEvent({:?})", event.delta);
-            mouse_dragged.send(MouseDraggedEvent { delta: event.delta });
+            mouse_dragged.send(MouseDraggedEvent { cursor_position, delta: event.delta });
         }
     } else {
         for event in mouse_wheel_input.iter() {
@@ -304,7 +355,7 @@ fn handle_mouse_inputs(
             if settings.layout.mode == LayoutMode::Line {
                 delta = Vec2::new(delta.y, delta.x);
             }
-            mouse_dragged.send(MouseDraggedEvent { delta: delta });
+            mouse_dragged.send(MouseDraggedEvent { cursor_position, delta: delta });
         }
     }
 }
