@@ -140,7 +140,7 @@ impl FretFingerData {
         if self.value.extra.pick {
             self.value.extra.fret = pick_note.and_then(|x| x.fret);
         } else {
-            self.value.extra.fret = shape.string_fret(self.value.extra.string);
+            self.value.extra.fret = shape.string_fret_with_barre(self.value.extra.string);
         }
         if let Some(fretboard) = fretboard {
             self.value.extra.capo = fretboard.capo;
@@ -162,7 +162,7 @@ impl FretFingerData {
     ) {
         self.update(commands, theme, entity);
         let scale = theme.guitar.calc_scale(self.value.extra.guitar_size.width);
-        if settings.show_guitar_syllable {
+        if settings.show_guitar_syllable && self.value.extra.fret.is_some() {
             theme.guitar.syllable_text.spawn_scaled_syllable_text(commands, entity, assets, settings, &self.value.calc_syllable(), scale)
         }
     }
