@@ -11,10 +11,10 @@ pub struct GuitarCapoData {
     pub guitar_size: LayoutSize,
 }
 
-impl GuitarCapoData {
-    pub fn new(capo: u8) -> Self {
+impl Default for GuitarCapoData {
+    fn default() -> Self {
         Self {
-            capo,
+            capo: 0,
             view_size: LayoutSize::ZERO,
             guitar_size: LayoutSize::ZERO,
         }
@@ -29,7 +29,6 @@ impl ShapeOp<NotationTheme, FillRectangle> for GuitarCapoData {
         let offset = if self.capo == 0 || self.guitar_size.width <= 0.0 {
             BevyUtil::offscreen_offset()
         } else {
-            let height = self.guitar_size.height * theme.guitar.capo_height_factor;
             let finger_radius = theme.guitar.string_x_factor * self.guitar_size.width / 2.0;
             let y = theme
                 .guitar
