@@ -12,12 +12,17 @@ pub struct NotationSettings {
     pub should_loop: bool,
     pub speed_factor: f32,
     pub hide_bar_number: bool,
+    pub show_guitar_syllable: bool,
     pub show_melody_syllable: bool,
     pub show_syllable_as_num: bool,
     pub always_show_fret: bool,
     pub melody_piano_mode: bool,
     pub allow_panning: bool,
     pub panning_line_size: f32,
+    pub hide_shapes_lane: bool,
+    pub hide_strings_lane: bool,
+    pub hide_lyrics_lane: bool,
+    pub hide_melody_lane: bool,
     pub override_beat_size: Option<f32>,
     pub override_chord_size: Option<f32>,
     pub override_guitar_width: Option<f32>,
@@ -31,12 +36,17 @@ impl Default for NotationSettings {
             should_loop: false,
             speed_factor: 1.0,
             hide_bar_number: false,
-            show_melody_syllable: false,
-            show_syllable_as_num: false,
+            show_guitar_syllable: true,
+            show_melody_syllable: true,
+            show_syllable_as_num: true,
             always_show_fret: false,
             melody_piano_mode: false,
             allow_panning: true,
             panning_line_size: 32.0,
+            hide_shapes_lane: false,
+            hide_strings_lane: false,
+            hide_lyrics_lane: false,
+            hide_melody_lane: false,
             override_beat_size: None,
             override_chord_size: None,
             override_guitar_width: None,
