@@ -71,9 +71,7 @@ impl ShapeOp<NotationTheme, OutlineRectangle> for PickNoteData {
         } else {
             let x = self.value.bar_size / self.bar_props.bar_units.0
                 * self.entry_props.in_bar_pos.0;
-            let y = -1.0
-                * theme.sizes.strings.string_space
-                * (self.value.pick_note.string as f32 - 1.0);
+            let y = theme.sizes.strings.calc_string_y(self.value.pick_note.string);
             let extra_z = if self.value.playing_state.is_current() {
                 1.0
             } else {
