@@ -10,6 +10,7 @@ use super::pick_note::{PickNoteData, PickNoteValue};
 
 pub fn on_entry_playing_changed(
     mut commands: Commands,
+    settings: Res<NotationSettings>,
     theme: Res<NotationTheme>,
     query: Query<(Entity, &EntryPlaying, &Children), Changed<EntryPlaying>>,
     mut note_query: QuerySet<(
@@ -19,6 +20,7 @@ pub fn on_entry_playing_changed(
     mut font_query: Query<&mut Text>,
 ) {
     if theme._bypass_systems { return; }
+    if settings.hide_strings_lane { return; }
     for (_entity, playing, children) in query.iter() {
         for child in children.iter() {
             if let Ok((entity, mut data, note_children)) = note_query.q0_mut().get_mut(*child) {
@@ -64,7 +66,7 @@ macro_rules! impl_pick_system {
                             let data =
                                 PickNoteData::new(entry, PickNoteValue::new(pick_note, syllable));
                             let note_entity = data.create(commands, theme, entity);
-                            if settings.always_show_fret || pick_note.fret.is_some() {
+                            if !settings.hide_strings_lane && (settings.always_show_fret || pick_note.fret.is_some()) {
                                 theme
                                     .texts.strings
                                     .spawn_fret_text(commands, note_entity, &assets, fret);
