@@ -1,10 +1,7 @@
-pub mod core_theme;
+pub mod theme_z;
 pub mod guitar_theme;
-pub mod lyrics_theme;
-pub mod melody_theme;
 pub mod notation_theme;
 pub mod shapes_theme;
-pub mod strings_theme;
 pub mod theme_colors;
 pub mod theme_sizes;
 pub mod theme_texts;
