@@ -52,7 +52,7 @@ impl TabTexts {
             commands,
             entity,
             text,
-            assets.en_font.clone(),
+            assets.latin_font.clone(),
             self.bar_font_size,
             self.bar_font_color,
             HorizontalAlign::Left,
@@ -99,7 +99,7 @@ impl ChordTexts {
             commands,
             entity,
             text,
-            assets.en_font.clone(),
+            assets.latin_font.clone(),
             self.bars_font_size,
             self.bars_font_color,
             HorizontalAlign::Right,
@@ -144,7 +144,7 @@ impl RhythmTexts {
             commands,
             entity,
             text,
-            assets.cn_font.clone(),
+            assets.lyrics_font.clone(),
             self.bar_font_size,
             self.bar_font_color,
             HorizontalAlign::Center,
@@ -189,7 +189,7 @@ impl LyricsTexts {
             commands,
             entity,
             text,
-            assets.cn_font.clone(),
+            assets.lyrics_font.clone(),
             self.word_font_size,
             self.word_font_color,
             HorizontalAlign::Right,
@@ -253,7 +253,7 @@ impl MelodyTexts {
             commands,
             entity,
             text.as_str(),
-            assets.en_font.clone(),
+            assets.latin_font.clone(),
             self.syllable_font_size * scale,
             self.syllable_font_color,
             if self.horizontal_center { HorizontalAlign::Center } else { HorizontalAlign::Right } ,
@@ -299,7 +299,7 @@ impl StringsTexts {
             commands,
             entity,
             text.as_str(),
-            assets.en_font.clone(),
+            assets.latin_font.clone(),
             self.fret_font_size,
             self.fret_font_color,
             HorizontalAlign::Right,
@@ -338,7 +338,7 @@ impl MiniMapTexts {
             commands,
             entity,
             text,
-            assets.cn_font.clone(),
+            assets.lyrics_font.clone(),
             self.bar_font_size,
             self.bar_font_color,
             HorizontalAlign::Center,
@@ -360,7 +360,7 @@ impl MiniMapTexts {
             commands,
             entity,
             text,
-            assets.en_font.clone(),
+            assets.latin_font.clone(),
             24.0,
             ThemeColors::hex_linear("000000"),
             HorizontalAlign::Center,
