@@ -46,7 +46,7 @@ impl<'a> View<NotationLayout<'a>> for ControlView {
         LayoutAnchor::CENTER
     }
     fn calc_size(&self, engine: &NotationLayout, constraint: LayoutConstraint) -> LayoutSize {
-        if Self::HUD_MODE || engine.state.hide_control {
+        if Self::HUD_MODE || !engine.state.show_control {
             LayoutSize::ZERO
         } else {
             LayoutSize::new(Self::MIN_WIDTH, constraint.max.height)
@@ -74,7 +74,7 @@ impl ControlView {
     pub fn calc_width(
         window_width: f32,
     ) -> f32 {
-        let width = window_width * 0.25;
+        let width = window_width * 0.30;
         if width < Self::MIN_WIDTH {
             Self::MIN_WIDTH
         } else if width > Self::MAX_WIDTH {
@@ -83,6 +83,12 @@ impl ControlView {
             width
         }
     }
+    pub fn is_pos_inside(
+        window_width: f32,
+        pos: Vec2,
+    ) -> bool {
+        window_width / 2.0 - pos.x <= ControlView::calc_width(window_width)
+    }
     pub fn overrides_ui(
         ui: &mut Ui,
         settings: &mut NotationSettings,
@@ -94,6 +100,20 @@ impl ControlView {
         CollapsingHeader::new("Override Sizes")
         .default_open(true)
         .show(ui, |ui| {
+            let mut override_tab_width = settings.layout.override_tab_width.is_some();
+            ui.checkbox(&mut override_tab_width, "Override Tab Width");
+            if override_tab_width {
+                let mut tab_width = settings.layout.override_tab_width.unwrap_or(512.0);
+                let last_tab_width = tab_width;
+                ui.add(Slider::new(&mut tab_width, 256.0..=1024.0).text("Tab Width"));
+                if settings.layout.override_tab_width.is_none() || float_ne!(tab_width, last_tab_width, abs <= 1.0) {
+                    settings.layout.override_tab_width = Some(tab_width);
+                    window_resized_evts.send(WindowResizedEvent());
+                }
+            } else if settings.layout.override_tab_width.is_some() {
+                settings.layout.override_tab_width = None;
+                window_resized_evts.send(WindowResizedEvent());
+            }
             let mut override_beat_size = settings.override_beat_size.is_some();
             ui.checkbox(&mut override_beat_size, "Override Beat Size");
             if override_beat_size {
@@ -426,30 +446,54 @@ impl ControlView {
     }
     pub fn tab_ui(
         ui: &mut Ui,
-        asset_server: &AssetServer,
+        pathes: &mut TabPathes,
         state: &mut NotationAppState,
         _settings: &mut NotationSettings,
         theme: &mut NotationTheme,
-        tab_pathes: &TabPathes,
     ) {
-        if tab_pathes.0.len() > 1 {
+        if theme._bypass_systems {
+            ui.label("Loading Tab ...");
+            return;
+        }
+        ui.horizontal(|ui| {
+            if ui.button("Reload Tab").clicked() {
+                Control::reload_tab(state, theme);
+            }
+            egui::warn_if_debug_build(ui);
+            ui.with_layout(egui::Layout::right_to_left(), |ui| {
+                #[cfg(not(target_arch = "wasm32"))]
+                if ui.button("Open Tab").clicked() {
+                    if let Some(path) = rfd::FileDialog::new()
+                            .add_filter("Fun Notation", &["ron"])
+                            .pick_file() {
+                        let path_str = path.clone().into_os_string().into_string();
+                        if let Ok(path_str) = path_str {
+                            pathes.0.insert(0, path_str.clone());
+                            state.change_tab(theme, path_str.clone());
+                        } else {
+                            println!("Failed to convert path to string: {:?} -> {:?}", path, path_str);
+                        }
+                    }
+                }
+                if ui.button("Help").clicked() {
+                    state.show_help = true;
+                }
+            });
+        });
+        if pathes.0.len() > 1 {
             let width = Self::calc_width(state.window_width);
             egui::ComboBox::from_label("")
                 .selected_text(state.tab_path.clone())
                 .width(width - 24.0)
                 .show_ui(ui, |ui| {
-                    for path in tab_pathes.0.iter() {
+                    for path in pathes.0.iter() {
                         if ui.selectable_label(*path == state.tab_path, path).clicked()
                         {
-                            theme._bypass_systems = true;
-                            state.change_tab(asset_server, path.clone());
+                            state.change_tab(theme, path.clone());
                         }
                     }
                 });
         }
-        if ui.button("Reset Tab").clicked() {
-            Control::reload_tab(state, theme);
-        }
     }
     pub fn guitar_tab_display_ui(
         ui: &mut Ui,
@@ -621,11 +665,10 @@ impl ControlView {
     pub fn control_ui(
         egui_ctx: Res<EguiContext>,
         mut windows: ResMut<Windows>,
-        asset_server: Res<AssetServer>,
+        mut pathes: ResMut<TabPathes>,
         mut state: ResMut<NotationAppState>,
         mut settings: ResMut<NotationSettings>,
         mut theme: ResMut<NotationTheme>,
-        tab_pathes: Res<TabPathes>,
         mut midi_settings: ResMut<MidiSettings>,
         mut midi_state: ResMut<MidiState>,
         mut play_control_evts: EventWriter<PlayControlEvent>,
@@ -633,7 +676,7 @@ impl ControlView {
         mut guitar_view_query: Query<&mut Transform, With<Arc<GuitarView>>>,
         mut jump_to_bar_evts: EventWriter<JumpToBarEvent>,
     ) {
-        if state.hide_control {
+        if !state.show_control || state._egui_needs_set_fonts {
             return;
         }
         let width = Self::calc_width(state.window_width);
@@ -649,7 +692,7 @@ impl ControlView {
                     }
                     ui.separator();
                      */
-                    Self::tab_ui(ui, &asset_server, &mut state, &mut settings, &mut theme, &tab_pathes);
+                    Self::tab_ui(ui, &mut pathes, &mut state, &mut settings, &mut theme);
                     ui.separator();
                     Self::play_control_ui(ui, &mut settings, &mut midi_state, &mut play_control_evts);
                     ui.separator();
